'********************************************************************
'*
'* File:           DnsImport.vbs 
'* Created:        September 1999
'* Version:        1.0
'*
'*  Main Function:  Import DNS Server Information from an Excel Spreadsheet or file.
'*
'*  DnsImport.vbs  [/S <server>] [/U <username>] [/W <password>]
'*                 [/O <outputfile>] /I <ImportFileName> [/Z zonename] [/D domainName] 
'*
'* Copyright (C) 1999 Microsoft Corporation
'*
'********************************************************************

OPTION EXPLICIT

    'Define constants
    CONST CONST_ERROR                   = 0
    CONST CONST_WSCRIPT                 = 1
    CONST CONST_CSCRIPT                 = 2
    CONST CONST_SHOW_USAGE              = 3
    CONST CONST_IMPORT                  = 4

    'Declare variables
    Dim intOpMode
    Dim strServer, strUserName, strPassword, strOutputFile, strImportFile, strImportZone, strImportDomain

    'Make sure the host is csript, if not then abort
    VerifyHostIsCscript()

    'Parse the command line
    intOpMode = intParseCmdLine(strServer     ,  _
                                strUserName   ,  _
                                strPassword   ,  _
                                strOutputFile ,  _
                                strImportZone ,  _
                                strImportDomain ,  _
                                strImportFile    )


    Select Case intOpMode

        Case CONST_SHOW_USAGE
            Call ShowUsage()

        Case CONST_IMPORT
            Call ImportType(strServer      , _
                            strOutputFile  , _
                            strUserName    , _
                            strPassword    , _
                            strImportZone   , _
                            strImportDomain ,  _
                            strImportFile    )

        Case CONST_ERROR
            'Do Nothing

        Case Else                    'Default -- should never happen
            Call Wscript.Echo("Error occurred in passing parameters.")

    End Select

'********************************************************************
'* End of Script
'********************************************************************

'********************************************************************
'*
'* Sub ImportType()
'*
'* Purpose: Determine if file is Excel or a Text file based off of the extention.
'*
'* Input:   strServer           a machine name
'*          strOutputFile       an output file name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strImportFile       The Excel Spreadsheet to import the data to
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************
Private Sub ImportType(strServer, strOutputFile, strUserName, strPassword, strInputZone, strInputDomain, strImportFile)

    If LCase(Right(strImportFile,4)) = ".xls" then
        Call ExcelImport(strServer, strOutputFile, strUserName, strPassword, strImportFile)
    Else
        Call TextImport(strServer, strOutputFile, strUserName, strPassword, strInputZone, strInputDomain, strImportFile)
    End If

End Sub

'********************************************************************
'*
'* Sub ExcelImport()
'*
'* Purpose: Import DNS Server Information from an Excel Spreadsheet.
'*
'* Input:   strServer           a machine name
'*          strOutputFile       an output file name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strImportFile       The Excel Spreadsheet to import the data to
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************
Private Sub ExcelImport(strServer, strOutputFile, strUserName, strPassword, strImportFile)

    'on error resume next

    Dim objFileSystem, objOutputFile, objService, objDNSSet, objDNS, objDNSServer, objFileSys, objFile
    Dim WSHShell, appExcel
    Dim strQuery, strMessage, strDataFile, strContainerName, strDNSServer, strOwnerName, strRecorddata, strTTL, strValue
    Dim intRow, intType
    Dim strMasters(0)
    Dim blnReverse

    'Open a text file for output if the file is requested
    If Not IsEmpty(strOutputFile) Then
        If (NOT blnOpenFile(strOutputFile, objOutputFile)) Then
            Call Wscript.Echo ("Could not open an output file.")
            Exit Sub
        End If
    End If

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    'Open Excel File
    Call WriteLine("Opening Excel File " & strImportFile & ".", objOutputFile)
    Set WSHShell = WScript.CreateObject("WScript.Shell")
    Set appExcel = Wscript.CreateObject("Excel.Application")    ' Display the application.
    appExcel.Visible = False    ' Open a sample document.
    
    Set objFileSys = CreateObject("Scripting.FileSystemObject")
    Set objFile=objFileSys.GetFile(strImportFile)
    If Err.Number = 0 Then
        appExcel.Workbooks.Open objFileSys.GetAbsolutePathName(strImportFile)
    Else
        Call WriteLine("Cannot Find File", objOutputFile)
    End If
        
    If blnErrorOccurred("Opening Excel File") then
        appExcel.activeworkbook.Close False
        appExcel.Quit
        Exit Sub
    End If
    
    'Check Excel File
    Call WriteLine("Validating Excel File.", objOutputFile)
    appExcel.Sheets("Zones").Select
    appExcel.Range("C1").Select
    If Not appExcel.ActiveCell.Text = "Reverse" then
        Call WriteLine("The Spreadsheet does not contain DNS Server Information.", objOutputFile)
        appExcel.activeworkbook.Close False
        appExcel.Quit
        Exit Sub
    End If
    If blnErrorOccurred("Opening Excel Import File") then
        appExcel.activeworkbook.Close False
        appExcel.Quit
        Exit Sub
    End If
    
    'Get Server Name
    Call WriteLine("Getting DNS Server Name.", objOutputFile)
    Set objDnsServer = objService.Get("MicrosoftDNS_Server.Name="".""")
    strDnsServer = objDnsServer.Name
    If blnErrorOccurred("Getting Server Name") then
        appExcel.activeworkbook.Close False
        appExcel.Quit
        Exit Sub
    End If

    'Import Zones
    Call WriteLine("Importing Zones.", objOutputFile)
    appExcel.Sheets("Zones").Select
    intRow = 2
    Set objDNSSet = objservice.Get("MicrosoftDNS_Zone")
    Do until blnCheckForEmptyCell("A", intRow, appExcel)

        appExcel.Range("A" & intRow).Select
        strContainerName = appExcel.ActiveCell.Text

        appExcel.Range("B" & intRow).Select
        Select Case lcase(appExcel.ActiveCell.Text)
            Case "primary"
                intType = 1
            Case "secondary"
                intType = 2
            Case "ds"
                intType = 0
            Case Else
                'Error Checking
        End Select
        
        appExcel.Range("C" & intRow).Select
        If lcase(appExcel.ActiveCell.Text) = "true" then
            blnReverse = True
        Else
            blnReverse = False
        End If

        appExcel.Range("D" & intRow).Select
        strDataFile = appExcel.ActiveCell.Text

        appExcel.Range("E" & intRow).Select
        strMasters(0) = appExcel.ActiveCell.Text

        'Set objDNS  = objDNSSet.SpawnInstance_
        Call WriteLine("  Creating Zone " & strContainerName & ".", objOutputFile)
        I = objDnsSet.CreateZone(strContainerName, intType,strDataFile,strMasters)
        intRow = intRow + 1
        If blnErrorOccurred("Creating Zone") then
            appExcel.activeworkbook.Close False
            appExcel.Quit
        End If
    Loop

    'Import A
    Call WriteLine("Importing A Records", objOutputFile)
    appExcel.Sheets("A").Select
    intRow = 2
    Set objDNSSet = objservice.Get("MicrosoftDNS_AType")
    Do until blnCheckForEmptyCell("A", intRow, appExcel)

        appExcel.Range("A" & intRow).Select
        strContainerName = appExcel.ActiveCell.Text

        appExcel.Range("B" & intRow).Select
        strOwnerName = appExcel.ActiveCell.Text
        
        appExcel.Range("C" & intRow).Select
        strRecorddata = appExcel.ActiveCell.Text

        appExcel.Range("D" & intRow).Select
        strTTL = appExcel.ActiveCell.Text

        Set objDNS  = objDNSSet.SpawnInstance_
            Call WriteLine("  Creating A Record " & strOwnerName & ".", objOutputFile)
            objDNS.ContainerName = strContainerName
            objDNS.OwnerName = strOwnerName
            objDns.RecordData = strRecorddata
            objDns.TTL = strTTL

        objDns.Put_
        intRow = intRow + 1
        If blnErrorOccurred("Creating A Record") then
            appExcel.activeworkbook.Close False
            appExcel.Quit
        End If
    Loop

    'Import Cname
    Call WriteLine("Importing CNAME Records", objOutputFile)
    appExcel.Sheets("CNAME").Select
    intRow = 2
    Set objDNSSet = objservice.Get("MicrosoftDNS_CNAMEType")
    Do until blnCheckForEmptyCell("A", intRow, appExcel)

        appExcel.Range("A" & intRow).Select
        strContainerName = appExcel.ActiveCell.Text

        appExcel.Range("B" & intRow).Select
        strOwnerName = appExcel.ActiveCell.Text
        
        appExcel.Range("C" & intRow).Select
        strRecorddata = appExcel.ActiveCell.Text

        appExcel.Range("D" & intRow).Select
        strTTL = appExcel.ActiveCell.Text

        Set objDNS  = objDNSSet.SpawnInstance_
            Call WriteLine("  Creating CNAME Record " & strOwnerName & ".", objOutputFile)
            objDNS.ContainerName = strContainerName
            objDNS.OwnerName = strOwnerName
            objDns.RecordData = strRecorddata
            objDns.TTL = strTTL

        objDns.Put_
        intRow = intRow + 1
        If blnErrorOccurred("Creating CNAME Record") then
            appExcel.activeworkbook.Close False
            appExcel.Quit
        End If
    Loop

    'Import MX
    Call WriteLine("Importing MX Records", objOutputFile)
    appExcel.Sheets("MX").Select
    intRow = 2
    Set objDNSSet = objservice.Get("MicrosoftDNS_MXType")
    Do until blnCheckForEmptyCell("A", intRow, appExcel)

        appExcel.Range("A" & intRow).Select
        strContainerName = appExcel.ActiveCell.Text

        appExcel.Range("B" & intRow).Select
        strOwnerName = appExcel.ActiveCell.Text
        
        appExcel.Range("C" & intRow).Select
        strRecorddata = appExcel.ActiveCell.Text

        appExcel.Range("D" & intRow).Select
        strValue = appExcel.ActiveCell.Text

        appExcel.Range("E" & intRow).Select
        strTTL = appExcel.ActiveCell.Text

        Set objDNS  = objDNSSet.SpawnInstance_
            Call WriteLine("  Creating MX Record " & strOwnerName & ".", objOutputFile)
            objDNS.ContainerName = strContainerName
            objDNS.OwnerName = strOwnerName
            objDns.RecordData = strValue & " " & strRecorddata
            objDns.TTL = strTTL

        objDns.Put_
        intRow = intRow + 1
        If blnErrorOccurred("Creating MX Record") then
            appExcel.activeworkbook.Close False
            appExcel.Quit
        End If
    Loop

    'Import PTR
    Call WriteLine("Importing PTR Records", objOutputFile)
    appExcel.Sheets("PTR").Select
    intRow = 2
    Set objDNSSet = objservice.Get("MicrosoftDNS_PTRType")
    Do until blnCheckForEmptyCell("A", intRow, appExcel)

        appExcel.Range("A" & intRow).Select
        strContainerName = appExcel.ActiveCell.Text

        appExcel.Range("B" & intRow).Select
        strOwnerName = appExcel.ActiveCell.Text
        
        appExcel.Range("C" & intRow).Select
        strRecorddata = appExcel.ActiveCell.Text

        appExcel.Range("D" & intRow).Select
        strTTL = appExcel.ActiveCell.Text

        Set objDNS  = objDNSSet.SpawnInstance_
            Call WriteLine("  Creating PTR Record " & strOwnerName & ".", objOutputFile)
            objDNS.ContainerName = strContainerName
            objDNS.OwnerName = strOwnerName
            objDns.RecordData = strRecorddata
            objDns.TTL = strTTL

        objDns.Put_
        intRow = intRow + 1
        If blnErrorOccurred("Creating PTR Record") then
            appExcel.activeworkbook.Close False
            appExcel.Quit
        End If
    Loop

    'Close SpreadSheet
    appExcel.activeworkbook.Close False
    appExcel.Quit

    If IsObject(objOutputFile) Then
        objOutputFile.Close
        Call Wscript.Echo ("Results are saved in file " & strOutputFile & ".")
    End If

End Sub

'********************************************************************
'*
'* Sub TextImport()
'*
'* Purpose: Import DNS Server Information from a Text File.
'*
'* Input:   strServer           a machine name
'*          strOutputFile       an output file name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strImportFile       The Excel Spreadsheet to import the data to
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************
Private Sub TextImport(strServer, strOutputFile, strUserName, strPassword, strInputZone, strInputDomain, strImportFile)

    on error resume next

    Dim objFileSystem, objOutputFile, objService, objDNSSet, objDNS, objDNSServer, objFileSys, objFile, objInParam, objoutParam, objMethod
    Dim strQuery, strMessage, strDataFile, strContainerName, strDNSServer, strOwnerName, strRecorddata, strTTL, strValue, strLine
    Dim intType
    Dim strMasters(0)
    Dim blnReverse

    'Open a text file for output if the file is requested
    If Not IsEmpty(strOutputFile) Then
        If (NOT blnOpenFile(strOutputFile, objOutputFile)) Then
            Call Wscript.Echo ("Could not open an output file.")
            Exit Sub
        End If
    End If

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    'Open Text File
    Call WriteLine("Opening Text File " & strImportFile & ".", objOutputFile)
    
    Set objFileSys = CreateObject("Scripting.FileSystemObject")
    Set objFile=objFileSys.OpenTextFile(strImportFile)

    If blnErrorOccurred("Opening Text File") then
        Exit Sub
    End If
    
    'Get Server Name
    Call WriteLine("Getting DNS Server Name.", objOutputFile)
    Set objDnsServer = objService.Get("MicrosoftDNS_Server.Name="".""")
    strDnsServer = objDnsServer.Name
    If blnErrorOccurred("Getting Server Name") then
        appExcel.activeworkbook.Close False
        appExcel.Quit
        Exit Sub
    End If
    Do While objFile.AtEndOfStream <> True
        strLine = objFile.ReadLine
        Select Case strFindType(strLine)
            Case "A"
                'Import A
                Set objDNSSet = objservice.Get("MicrosoftDNS_AType")

                Set objMethod = objDNSSet.Methods_("CreateInstanceFromPropertyData")
                Set ObjInParam = objMethod.inParameters.SpawnInstance_()

                If Not IsEmpty(strInputDomain) then
                    If strGetElement(strLine,1) = "(same as parent folder)" then
                        objInParam.OwnerName = strInputDomain
                    ElseIf Right(strGetElement(strLine,1),1) = "." then
                        objInParam.OwnerName = strGetElement(strLine,1)
                    Else
                        objInParam.OwnerName = strGetElement(strLine,1) & "." & strInputDomain & "."
                    End If
                Else
                    If strGetElement(strLine,1) = "(same as parent folder)" then
                        objInParam.OwnerName = strInputZone
                    ElseIf Right(strGetElement(strLine,1),1) = "." then
                        objInParam.OwnerName = strGetElement(strLine,1)
                    Else
                        objInParam.OwnerName = strGetElement(strLine,1) & "." & strInputZone & "."
                    End If
                End If
                objInParam.ContainerName = strInputZone
                objInParam.DNSServerName = strDnsServer
                objInParam.IPAddress = strGetElement(strLine,3)
                objInParam.RecordClass = 1
                
                Wscript.Echo("Creating A Record : " & objInParam.OwnerName)
               
                Set objOutParam = objDNSSet.ExecMethod_("CreateInstanceFromPropertyData", objInParam)

            Case "PTR"
                'Import PTR
                Set objDNSSet = objservice.Get("MicrosoftDNS_PTRType")

                Set objMethod = objDNSSet.Methods_("CreateInstanceFromPropertyData")
                Set ObjInParam = objMethod.inParameters.SpawnInstance_()

                If Not IsEmpty(strInputDomain) then
                    If strGetElement(strLine,1) = "(same as parent folder)" then
                        objInParam.OwnerName = strInputDomain
                    ElseIf Right(strGetElement(strLine,1),1) = "." then
                        objInParam.OwnerName = strGetElement(strLine,1)
                    Else
                        objInParam.OwnerName = strGetElement(strLine,1) & "." & strInputDomain & "."
                    End If
                Else
                    If strGetElement(strLine,1) = "(same as parent folder)" then
                        objInParam.OwnerName = strInputZone
                    ElseIf Right(strGetElement(strLine,1),1) = "." then
                        objInParam.OwnerName = strGetElement(strLine,1)
                    Else
                        objInParam.OwnerName = strGetElement(strLine,1) & "." & strInputZone & "."
                    End If
                End If
                objInParam.ContainerName = strInputZone
                objInParam.DNSServerName = strDnsServer
                objInParam.PTRDomainName = strGetElement(strLine,3)
                objInParam.RecordClass = 1
                
                Wscript.Echo("Creating PTR Record : " & objInParam.OwnerName)
               
                Set objOutParam = objDNSSet.ExecMethod_("CreateInstanceFromPropertyData", objInParam)

       
        End Select
       
    Loop
End Sub
'********************************************************************
'*
'* Function strFindType()
'*
'* Purpose: Returns a ResourceRecord Type based on a input line.
'*
'* Input:   strInput         An Input String
'*
'********************************************************************
Function strFindType(strInput)
    Dim I, intStart, intEnd
    intStart = 0
    For I = 1 to Len(strInput)
        If Mid(strInput, I, 1) = chr(9) then
            If intStart = 0 then
                intStart = I + 1
            Else
                intEnd = I
                Exit For
            End If
        End If
    Next
    strFindType = Mid(strInput, intStart, (intEnd - intStart))
End Function

'********************************************************************
'*
'* Function strGetElement()
'*
'* Purpose: Returns a ResourceRecord Type based on a input line.
'*
'* Input:   strInput         An Input String
'*          intElement       The Element number to retrieve
'*
'********************************************************************
Function strGetElement(strInput, intElement)
    Dim I, intStart, intEnd
    intStart = 0
    If intElement = 1 then
        intStart = 1
    End If
    intElement = intElement - 1
    For I = 1 to Len(strInput)
        If Mid(strInput, I, 1) = chr(9) then
            intElement = intElement - 1
            If Not intElement > 0 then
                If intStart = 0 then
                    intStart = I + 1
                Else
                    intEnd = I
                    Exit For
                End If
            End If
        End If
    Next
    If IsEmpty(intEnd) Then
        intEnd = Len(strInput) + 1
    End If
    strGetElement = Mid(strInput, intStart, (intEnd - intStart))
End Function

'********************************************************************
'*
'* Function blnCheckForEmptyCell()
'*
'* Purpose: Returns a true if the cell is empty.
'*
'* Input:   strColumn        The Column
'*          intRow           The Row
'*          appExcel         An Excel Application Object
'*
'********************************************************************
Function blnCheckForEmptyCell(strColumn, intRow, appExcel)
    appExcel.Range(strColumn & intRow).Select
    If appExcel.ActiveCell.Text = "" then
        blnCheckForEmptyCell = True
    Else
        blnCheckForEmptyCell = False
    End If
End Function

'********************************************************************
'*
'* Function intParseCmdLine()
'*
'* Purpose: Parses the command line.
'* Input:   
'*
'* Output:  strServer         a remote server ("" = local server")
'*          strUserName       the current user's name
'*          strPassword       the current user's password
'*          strOutputFile     an output file name
'*
'********************************************************************
Private Function intParseCmdLine( ByRef strServer     , _
                                  ByRef strUserName   , _
                                  ByRef strPassword   , _
                                  ByRef strOutputFile , _
                                  ByRef strInputZone  , _
                                  ByRef strInputDomain , _
                                  ByRef strImportFile   )


    'on error resume next

    Dim strFlag
    Dim intState, intArgIter
    Dim objFileSystem

    If Wscript.Arguments.Count > 0 Then
        strFlag = Wscript.arguments.Item(0)
    End If

    If IsEmpty(strFlag) Then                'No arguments have been received
        intParseCmdLine = CONST_LIST
        Exit Function
    End If

    'Check if the user is asking for help or is just confused
    If (strFlag="help") OR (strFlag="/h") OR (strFlag="\h") OR (strFlag="-h") _
        OR (strFlag = "\?") OR (strFlag = "/?") OR (strFlag = "?") _ 
        OR (strFlag="h") Then
        intParseCmdLine = CONST_SHOW_USAGE
        Exit Function
    End If

    'Retrieve the command line and set appropriate variables
     intArgIter = 0
    Do While intArgIter <= Wscript.arguments.Count - 1
        Select Case Left(LCase(Wscript.arguments.Item(intArgIter)),2)
  
            Case "/s"
                If Not blnGetArg("Server", strServer, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case "/o"
                If Not blnGetArg("Output File", strOutputFile, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case "/u"
                If Not blnGetArg("User Name", strUserName, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case "/w"
                If Not blnGetArg("User Password", strPassword, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1
            
            Case "/i"
                intParseCmdLine = CONST_IMPORT
                If Not blnGetArg("Import File", strImportFile, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case "/z"
                If Not blnGetArg("Import Zone", strImportZone, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case "/d"
                If Not blnGetArg("Import Domain", strImportDomain, intArgIter) Then
                    intParseCmdLine = CONST_ERROR
                    Exit Function
                End If
                intArgIter = intArgIter + 1

            Case Else 'We shouldn't get here
                Call Wscript.Echo("Invalid or misplaced parameter: " _
                   & Wscript.arguments.Item(intArgIter) & vbCRLF _
                   & "Please check the input and try again," & vbCRLF _
                   & "or invoke with '/?' for help with the syntax.")
                Wscript.Quit

        End Select

    Loop '** intArgIter <= Wscript.arguments.Count - 1

    If IsEmpty(strImportFile) Then
        intPArseCmdLine = CONST_ERROR
    End If

End Function

'********************************************************************
'*
'* Sub ShowUsage()
'*
'* Purpose: Shows the correct usage to the user.
'*
'* Input:   None
'*
'* Output:  Help messages are displayed on screen.
'*
'********************************************************************
Private Sub ShowUsage()

    Wscript.Echo ""
    Wscript.Echo "Import DNS Server Information from an Excel Spreadsheet or a text file."
    Wscript.Echo ""
    Wscript.Echo "SYNTAX:"
    Wscript.Echo "  DnsImport.vbs /I <ImportFile>"
    Wscript.Echo "[/S <server>] [/U <username>] [/W <password>]"
    Wscript.Echo "  [/O <outputfile>] </Z <zone> [/D <domain>]"
    Wscript.Echo ""
    Wscript.Echo "PARAMETER SPECIFIERS:"
    Wscript.Echo "   ImportFile    An Excel Spreadsheet."
    Wscript.Echo "   zone          The zone a text file should import records into."
    Wscript.Echo "   domain        The Domain a text file should import records into."
    Wscript.Echo "   server        A machine name."
    Wscript.Echo "   username      The current user's name."
    Wscript.Echo "   password      Password of the current user."
    Wscript.Echo "   outputfile    The output file name."
    Wscript.Echo ""
    Wscript.Echo "EXAMPLE:"
    Wscript.Echo "   cscript DnsImport.vbs /i c:\data\import.xls"
    Wscript.Echo "   Imports data into the local DNS Server from import.xls."
    Wscript.Echo ""
    Wscript.Echo "   cscript DnsImport.vbs /i c:\data\importfile.txt /z 236.57.157.in-addr.arpa"
    Wscript.Echo "   Imports data into the local DNS Server from importfile.txt."
    Wscript.Echo ""
    Wscript.Echo "   cscript DnsImport.vbs /i c:\data\importfile.txt /z foo.com /d domain.foo.com"
    Wscript.Echo "   Imports data into the local DNS Server from importfile.txt."

End Sub

'********************************************************************
'* General Routines
'********************************************************************

'********************************************************************
'*
'* Function strPackString()
'*
'* Purpose: Attaches spaces to a string to increase the length to intWidth.
'*
'* Input:   strString   a string
'*          intWidth    the intended length of the string
'*          blnAfter    Should spaces be added after the string?
'*          blnTruncate specifies whether to truncate the string or not if
'*                      the string length is longer than intWidth
'*
'* Output:  strPackString is returned as the packed string.
'*
'********************************************************************
Private Function strPackString( ByVal strString, _
                                ByVal intWidth,  _
                                ByVal blnAfter,  _
                                ByVal blnTruncate)

    'on error resume next

    intWidth      = CInt(intWidth)
    blnAfter      = CBool(blnAfter)
    blnTruncate   = CBool(blnTruncate)

    If Err.Number Then
        Call Wscript.Echo ("Argument type is incorrect!")
        Err.Clear
        Wscript.Quit
    End If

    If IsNull(strString) Then
        strPackString = "null" & Space(intWidth-4)
        Exit Function
    End If

    strString = CStr(strString)
    If Err.Number Then
        Call Wscript.Echo ("Argument type is incorrect!")
        Err.Clear
        Wscript.Quit
    End If

    If intWidth > Len(strString) Then
        If blnAfter Then
            strPackString = strString & Space(intWidth-Len(strString))
        Else
            strPackString = Space(intWidth-Len(strString)) & strString & " "
        End If
    Else
        If blnTruncate Then
            strPackString = Left(strString, intWidth-1) & " "
        Else
            strPackString = strString & " "
        End If
    End If

End Function

'********************************************************************
'* 
'*  Function blnGetArg()
'*
'*  Purpose: Helper to intParseCmdLine()
'* 
'*  Usage:
'*
'*     Case "/s" 
'*       blnGetArg ("server name", strServer, intArgIter)
'*
'********************************************************************
Private Function blnGetArg ( ByVal StrVarName,   _
                             ByRef strVar,       _
                             ByRef intArgIter) 

    blnGetArg = False 'failure, changed to True upon successful completion

    If Len(Wscript.Arguments(intArgIter)) > 2 then
        If Mid(Wscript.Arguments(intArgIter),3,1) = ":" then
            If Len(Wscript.Arguments(intArgIter)) > 3 then
                strVar = Right(Wscript.Arguments(intArgIter), _
                         Len(Wscript.Arguments(intArgIter)) - 3)
                blnGetArg = True
                Exit Function
            Else
                intArgIter = intArgIter + 1
                If intArgIter > (Wscript.Arguments.Count - 1) Then
                    Call Wscript.Echo( "Invalid " & StrVarName & ".")
                    Call Wscript.Echo( "Please check the input and try again.")
                    Exit Function
                End If

                strVar = Wscript.Arguments.Item(intArgIter)
                If Err.Number Then
                    Call Wscript.Echo( "Invalid " & StrVarName & ".")
                    Call Wscript.Echo( "Please check the input and try again.")
                    Exit Function
                End If

                If InStr(strVar, "/") Then
                    Call Wscript.Echo( "Invalid " & StrVarName)
                    Call Wscript.Echo( "Please check the input and try again.")
                    Exit Function
                End If

                blnGetArg = True 'success
            End If
        Else
            strVar = Right(Wscript.Arguments(intArgIter), _
                     Len(Wscript.Arguments(intArgIter)) - 2)
            blnGetArg = True 'success
            Exit Function
        End If
    Else
        intArgIter = intArgIter + 1
        If intArgIter > (Wscript.Arguments.Count - 1) Then
            Call Wscript.Echo( "Invalid " & StrVarName & ".")
            Call Wscript.Echo( "Please check the input and try again.")
            Exit Function
        End If

        strVar = Wscript.Arguments.Item(intArgIter)
        If Err.Number Then
            Call Wscript.Echo( "Invalid " & StrVarName & ".")
            Call Wscript.Echo( "Please check the input and try again.")
            Exit Function
        End If

        If InStr(strVar, "/") Then
            Call Wscript.Echo( "Invalid " & StrVarName)
            Call Wscript.Echo( "Please check the input and try again.")
            Exit Function
        End If
        blnGetArg = True 'success
    End If
End Function

'********************************************************************
'*
'* Function blnConnect()
'*
'* Purpose: Connects to machine strServer.
'*
'* Input:   strServer       a machine name
'*          strNameSpace    a namespace
'*          strUserName     name of the current user
'*          strPassword     password of the current user
'*
'* Output:  objService is returned  as a service object.
'*          strServer is set to local host if left unspecified
'*
'********************************************************************
Private Function blnConnect(ByVal strNameSpace, _
                            ByVal strUserName,  _
                            ByVal strPassword,  _
                            ByRef strServer,    _
                            ByRef objService)

    'on error resume next

    Dim objLocator, objWshNet

    blnConnect = False     'There is no error.

    'Create Locator object to connect to remote CIM object manager
    Set objLocator = CreateObject("WbemScripting.SWbemLocator")
    If Err.Number then
        Call Wscript.Echo( "Error 0x" & CStr(Hex(Err.Number)) & _
                           " occurred in creating a locator object." )
        If Err.Description <> "" Then
            Call Wscript.Echo( "Error description: " & Err.Description & "." )
        End If
        Err.Clear
        blnConnect = True     'An error occurred
        Exit Function
    End If

    'Connect to the namespace which is either local or remote
    Set objService = objLocator.ConnectServer (strServer, strNameSpace, _
       strUserName, strPassword)
    ObjService.Security_.impersonationlevel = 3
    If Err.Number then
        Call Wscript.Echo( "Error 0x" & CStr(Hex(Err.Number)) & _
                           " occurred in connecting to server " _
           & strServer & ".")
        If Err.Description <> "" Then
            Call Wscript.Echo( "Error description: " & Err.Description & "." )
        End If
        Err.Clear
        blnConnect = True     'An error occurred
    End If

    'Get the current server's name if left unspecified
    If IsEmpty(strServer) Then
        Set objWshNet = CreateObject("Wscript.Network")
    strServer     = objWshNet.ComputerName
    End If

End Function

'********************************************************************
'*
'* Sub      VerifyHostIsCscript()
'*
'* Purpose: Determines which program is used to run this script.
'*
'* Input:   None
'*
'* Output:  If host is not cscript, then an error message is printed 
'*          and the script is aborted.
'*
'********************************************************************
Sub VerifyHostIsCscript()

    'on error resume next

    Dim strFullName, strCommand, i, j, intStatus

    strFullName = WScript.FullName

    If Err.Number then
        Call Wscript.Echo( "Error 0x" & CStr(Hex(Err.Number)) & " occurred." )
        If Err.Description <> "" Then
            Call Wscript.Echo( "Error description: " & Err.Description & "." )
        End If
        intStatus =  CONST_ERROR
    End If

    i = InStr(1, strFullName, ".exe", 1)
    If i = 0 Then
        intStatus =  CONST_ERROR
    Else
        j = InStrRev(strFullName, "\", i, 1)
        If j = 0 Then
            intStatus =  CONST_ERROR
        Else
            strCommand = Mid(strFullName, j+1, i-j-1)
            Select Case LCase(strCommand)
                Case "cscript"
                    intStatus = CONST_CSCRIPT
                Case "wscript"
                    intStatus = CONST_WSCRIPT
                Case Else       'should never happen
                    Call Wscript.Echo( "An unexpected program was used to " _
                                       & "run this script." )
                    Call Wscript.Echo( "Only CScript.Exe or WScript.Exe can " _
                                       & "be used to run this script." )
                    intStatus = CONST_ERROR
                End Select
        End If
    End If

    If intStatus <> CONST_CSCRIPT Then
        Call WScript.Echo( "Please run this script using CScript." & vbCRLF & _
             "This can be achieved by" & vbCRLF & _
             "1. Using ""CScript DnsImport.VBS arguments"" for Windows 95/98 or" _
             & vbCRLF & "2. Changing the default Windows Scripting Host " _
             & "setting to CScript" & vbCRLF & "    using ""CScript " _
             & "//H:CScript //S"" and running the script using" & vbCRLF & _
             "    ""DnsImport.vbs arguments"" for Windows NT/2000." )
        WScript.Quit
    End If

End Sub

'********************************************************************
'*
'* Sub WriteLine()
'* Purpose: Writes a text line either to a file or on screen.
'* Input:   strMessage  the string to print
'*          objFile     an output file object
'* Output:  strMessage is either displayed on screen or written to a file.
'*
'********************************************************************
Sub WriteLine(ByVal strMessage, ByVal objFile)

    'on error resume next
    If IsObject(objFile) then        'objFile should be a file object
        objFile.WriteLine strMessage
    Else
        Call Wscript.Echo( strMessage )
    End If

End Sub

'********************************************************************
'* 
'* Function blnErrorOccurred()
'*
'* Purpose: Reports error with a string saying what the error occurred in.
'*
'* Input:   strIn		string saying what the error occurred in.
'*
'* Output:  displayed on screen 
'* 
'********************************************************************
Private Function blnErrorOccurred (ByVal strIn)

    If Err.Number Then
        Call Wscript.Echo( "Error 0x" & CStr(Hex(Err.Number)) & ": " & strIn)
        If Err.Description <> "" Then
            Call Wscript.Echo( "Error description: " & Err.Description)
        End If
        Err.Clear
        blnErrorOccurred = True
    Else
        blnErrorOccurred = False
    End If

End Function

'********************************************************************
'* 
'* Function blnOpenFile
'*
'* Purpose: Opens a file.
'*
'* Input:   strFileName		A string with the name of the file.
'*
'* Output:  Sets objOpenFile to a FileSystemObject and setis it to 
'*            Nothing upon Failure.
'* 
'********************************************************************
Private Function blnOpenFile(ByVal strFileName, ByRef objOpenFile)

    'on error resume next

    Dim objFileSystem

    Set objFileSystem = Nothing

    If IsEmpty(strFileName) OR strFileName = "" Then
        blnOpenFile = False
        Set objOpenFile = Nothing
        Exit Function
    End If

    'Create a file object
    Set objFileSystem = CreateObject("Scripting.FileSystemObject")
    If blnErrorOccurred("Could not create filesystem object.") Then
        blnOpenFile = False
        Set objOpenFile = Nothing
        Exit Function
    End If

    'Open the file for output
    Set objOpenFile = objFileSystem.OpenTextFile(strFileName, 8, True)
    If blnErrorOccurred("Could not open") Then
        blnOpenFile = False
        Set objOpenFile = Nothing
        Exit Function
    End If
    blnOpenFile = True

End Function

'********************************************************************
'*                                                                  *
'*                           End of File                            *
'*                                                                  *
'********************************************************************


    